@@ -1,6 +1,6 @@
 import yaml
 
-from . import gv as gv
+from . import gvalues
 import os
 import platform
 
@@ -9,7 +9,7 @@ KEY_ARR_TMP = dict()
 
 
 def setModuleName(name):
-    gv.module_name = name
+    gvalues.module_name = name
 
 
 def initConfig():
@@ -20,11 +20,11 @@ def initConfig():
         ConfigPath = os.path.expanduser('~') + '/Config'
     ConfigFiles = GetFileFromThisRootDir(ConfigPath, ['yaml'])
     print(ConfigFiles)
-    gv.ConfigList = dict()
+    gvalues.ConfigList = dict()
     for file in ConfigFiles:
         f = open(file['path'])
-        gv.ConfigList[file['moduleName']] = yaml.load(f, Loader=yaml.FullLoader)
-    print(gv.ConfigList)
+        gvalues.ConfigList[file['moduleName']] = yaml.load(f, Loader=yaml.FullLoader)
+    print(gvalues.ConfigList)
 
 
 # 获取指定路径下所有指定后缀的文件
@@ -61,7 +61,7 @@ def GetFileFromThisRootDir(dir, ext=None):
 # 设置配置文件内容
 def setConfig(moduleName, key, value):
     global ConfigFiles
-    loader = gv.ConfigList[moduleName]
+    loader = gvalues.ConfigList[moduleName]
 
     key_arr = key.split('.')
     tmp_arr = []
@@ -80,7 +80,7 @@ def setConfig(moduleName, key, value):
 
 # 获取配置文件内容
 def getConfig(moduleName, key):
-    loader = gv.ConfigList[moduleName]
+    loader = gvalues.ConfigList[moduleName]
     key_arr = key.split('.')
     for key_str in key_arr:
         loader = loader[key_str]
